﻿using System;
using System.Windows;

namespace XamDateTimeEditorIssue
{
    public partial class DateRange
    {
        #region Properties
        public static readonly DependencyProperty DateFromProperty;
        public DateTime DateFrom
        {
            get { return (DateTime)GetValue(DateFromProperty); }
            set { SetValue(DateFromProperty, value); }
        }

        public static readonly DependencyProperty DateToProperty;
        public DateTime DateTo
        {
            get { return (DateTime)GetValue(DateToProperty); }
            set { SetValue(DateToProperty, value); }
        }
        #endregion

        #region .ctors
        static DateRange()
        {
            DateFromProperty = DependencyProperty.Register("DateFrom", typeof(DateTime), typeof(DateRange),
                                                           new FrameworkPropertyMetadata(DateTime.Now, new PropertyChangedCallback(DateRange_PropertyChanged),
                                                                                         DateFromProperty_CoerceValue));

            DateToProperty = DependencyProperty.Register("DateTo", typeof(DateTime), typeof(DateRange),
                                                           new FrameworkPropertyMetadata(DateTime.Now, new PropertyChangedCallback(DateRange_PropertyChanged),
                                                                                         DateToProperty_CoerceValue));
        }
        
        public DateRange()
        {
            InitializeComponent();
        }
        #endregion

        #region Private methods
        private static void DateRange_PropertyChanged(DependencyObject sender, DependencyPropertyChangedEventArgs e)
        {
            
        }

        private static object DateFromProperty_CoerceValue(DependencyObject sender, object value)
        {
            DateTime val = (DateTime)value;
            DateTime dateTo = ((DateRange)sender).DateTo;
            if (val.Date > dateTo.Date)
            {
                val = dateTo;
            }

            return val;
        }

        private static object DateToProperty_CoerceValue(DependencyObject sender, object value)
        {
            DateTime val = (DateTime)value;
            DateTime dateFrom = ((DateRange)sender).DateFrom;
            if (val.Date < dateFrom.Date)
            {
                val = dateFrom;
            }

            return val;
        }
        #endregion
    }
}
